import Acquisition
from Globals import Persistent

ELEMENT_NODE=1
ATTRIBUTE_NODE=2
TEXT_NODE=3
CDATA_SECTION_NODE=4
ENTITY_REFERENCE_NODE=5
ENTITY_NODE=6
PROCESSING_INSTRUCTION_NODE=7
COMMENT_NODE=8
DOCUMENT_NODE=9
DOCUMENT_TYPE_NODE=10
DOCUMENT_FRAGMENT_NODE=11
NOTATION_NODE=12

class IdGenerator:
    """Simple class to generate unique ids.
    """
    def __init__(self):
        self.count = 0

    def getId(self):
        result = "e%s" % self.count
        self.count = self.count + 1
        return result

# singleton instance of IdGenerator class
idGenerator = IdGenerator()

class ElementNode(Acquisition.Implicit, Persistent):
    """Contains the DOM data, but not the DOM methods (those are
    in the widgets which wrap around this.
    """
    nodeType = ELEMENT_NODE
    
    def __init__(self, nodeName):
        self.nodeName = nodeName
        self.attributes = {}
        self.childIds = []
        
    def setAttributes(self, attributes):
        self.attributes = attributes

    def setChildNodes(self, nodes):
        # set nodes as attributes of myself, store list of ids
        # by storing child nodes as attributes, we make the
        # acquisition mechanism work
        childIds = []
        for node in nodes:
            id = idGenerator.getId()
            node.id = id
            childIds.append(id)
            setattr(self, id, node)
        self.childIds = childIds

    def addChildNode(self, node):
        id = idGenerator.getId()
        node.id = id
        self.childIds.append(id)
        setattr(self, id, node)
        self.childIds = self.childIds
        
class TextNode(Acquisition.Implicit, Persistent):
    nodeType = TEXT_NODE
    nodeName = "#text"
    
    def __init__(self, text):
        self.text = text





