import OFS.SimpleItem 
import Acquisition                
import AccessControl.Role         

from Globals import Persistent
from Globals import HTMLFile

import Widget
from DomCore import ElementNode, TextNode

from whrandom import randint

class WidgetDomTest(
    OFS.SimpleItem.Item,
    Persistent,
    Acquisition.Implicit,
    AccessControl.Role.RoleManager):
    """Just a test Zope object that stores a DOMish tree. The
    XMLDocument equivalent.
    """
    
    meta_type = "WidgetDomTest"

    # the various tabs
    manage_options = (
        {'label' : 'Security', 'action' : 'manage_access'},
        )
    
    def __init__(self, id):
        self.id = id
        
        # build a DOMish tree
        
        # warning! if you make numbers too large, you'll get VAST
        # trees. exponential growth!

        # 3 levels deep, 4 subnodes nodes per level
        self._dom = build_tree(3, 4)
                
        # build simple domcore tree
        #self._dom = ElementNode('foo', {},
        #                        [ElementNode('bar', {}, [TextNode('text')]),
        #                         ElementNode('baz', {}, [])])
        
    def getDOM(self):
        """Get the top of the tree, wrapped.
        """
        return Widget.wrap(self._dom)

def build_tree(levels, node_amount):
    """Recursive function that can create random DOMish tree.
    """
    # create new node (random put in nodename so we can see they're different)
    node = ElementNode("node %s" % randint(0, 1000))
    # if we don't have anything more to add, we're done
    if levels == 0:
        return node
    # otherwise, add new child nodes
    nodes = []
    for i in range(node_amount):
        nodes.append(build_tree(levels - 1, node_amount))
    # make them child nodes of node
    node.setChildNodes(nodes)
    return node
    
manage_addWidgetDomTestForm = HTMLFile('widgetDomTestAdd', globals())

def manage_addWidgetDomTest(self, id, title='', REQUEST=None):
    """Add widgetDomTest
    """
    widgetDomTest = WidgetDomTest(id)
    
    self._setObject(id, widgetDomTest)
    if REQUEST is not None:
        return self.manage_main(self, REQUEST)

